@@ -206,7 +206,7 @@ namespace Tomboy
 			font_peditor.AddGuard (font_button);
 			
 			// New Note Template
-			
+			// Translators: This is 'New Note' Template, not New 'Note Template'
 			label = MakeLabel (Catalog.GetString ("New Note Template"));
 			options_list.PackStart (label, false, false, 0);
 
@@ -219,9 +219,8 @@ namespace Tomboy
 			align.Show ();
 			options_list.PackStart (align, false, false, 0);
 			
-			Gtk.LinkButton open_template_button = new Gtk.LinkButton (
-				String.Empty,
-				Catalog.GetString ("Open New Note Template"));
+			Gtk.Button open_template_button = new Gtk.Button ();
+			open_template_button.Label = Catalog.GetString ("Open New Note Template");
 
 			open_template_button.Clicked += OpenTemplateButtonClicked;
 			open_template_button.Show ();
@@ -886,9 +885,8 @@ namespace Tomboy
 			Gtk.Dialog advancedDlg =
 			        new Gtk.Dialog (Catalog.GetString ("Other Synchronization Options"),
 			                        this,
-			                        Gtk.DialogFlags.DestroyWithParent | Gtk.DialogFlags.Modal,
+			                        Gtk.DialogFlags.DestroyWithParent | Gtk.DialogFlags.Modal | Gtk.DialogFlags.NoSeparator,
 			                        Gtk.Stock.Close, Gtk.ResponseType.Close);
-
 			// Populate dialog
 			Gtk.Label label =
 			        new Gtk.Label (Catalog.GetString ("When a conflict is detected between " +
@@ -1161,16 +1159,21 @@ namespace Tomboy
 
 				// Give the user a visual letting them know that connecting
 				// was successful.
+				// TODO: Replace Yes/No with Sync/Close
 				dialog =
 				        new HIGMessageDialog (this,
 				                              Gtk.DialogFlags.Modal,
 				                              Gtk.MessageType.Info,
-				                              Gtk.ButtonsType.Close,
+				                              Gtk.ButtonsType.YesNo,
 				                              Catalog.GetString ("Success! You're connected!"),
 				                              Catalog.GetString (
-				                                      "Tomboy is ready to synchronize your notes."));
-				dialog.Run ();
+				                                      "Tomboy is ready to synchronize your notes. Would you like to synchronize them now?"));
+				int response = dialog.Run ();
 				dialog.Destroy ();
+
+				if (response == (int) Gtk.ResponseType.Yes)
+					// TODO: Put this voodoo in a method somewhere
+					Tomboy.ActionManager ["NoteSynchronizationAction"].Activate ();
 			} else {
 				// TODO: Change the SyncServiceAddin API so the call to
 				// SaveConfiguration has a way of passing back an exception
@@ -1232,7 +1235,7 @@ namespace Tomboy
 
 			// TODO: Change this icon to be an addin/package icon
 			Gtk.Image icon =
-			        new Gtk.Image (Gtk.Stock.Info, Gtk.IconSize.Dialog);
+			        new Gtk.Image (Gtk.Stock.DialogInfo, Gtk.IconSize.Dialog);
 			icon.Yalign = 0;
 
 			info_label = new Gtk.Label ();
